<?php
/*
Plugin Name: WpQrc
Plugin URI: http://pep2a.fr/
Description: WpQrc plugin de gestion des actions qrcode
Version: 0.2
Author: alain messin
*/

/*  Copyright 2021 pep2a
 Ce plugin est fourni sans aucune garantie et est utilisable dans le cadre d'une license Creative Common Share Alike <a href="https://creativecommons.org/licenses/by-sa/4.0/deed.fr">https://creativecommons.org/licenses/by-sa/4.0/deed.fr</a>. Ce plugin est entièrement gratuit, cependant des contributions <a href="https://pep2a.fr/dons/">en dons</a> ou <a href="https://pep2a.fr/souscrire/">en souscription</a> à notre coopérative  ainsi que toute aide seront les bienvenus.
*/

/**
 * Exit if accessed directly
 */

///alm 20210915 06:29

if ( !defined( 'ABSPATH' ) ) {
    exit;
}

/**
 * Base class
 */
if ( !class_exists( 'WpQrc' ) ) {

    final class WpQrc {
        /**
         * Constructeur
         */
        public function __construct() {
			// variables generales du plugin
            $this->plugin_prefix = 'wpqrc_';
            $this->plugin_basefile_path = __FILE__;
            $this->plugin_dir_path = plugin_dir_path(__FILE__) ;
			$this->plugin_template_path = $this->plugin_dir_path.'templates/';

            $this->plugin_basefile = plugin_basename( $this->plugin_basefile_path );
            $this->plugin_url = plugin_dir_url( $this->plugin_basefile );
            $this->plugin_path = trailingslashit( dirname( $this->plugin_basefile_path ) );

			$this->includes_path = $this->plugin_dir_path.'includes/';
            $this->plugin_textdomain = 'wpqrc' ;

			// permissions
			//capability to read plugin data
            $this->plugin_read_capability='read';
            //capability to edit plugin data
            $this->plugin_edit_capability='edit_pages';
            //access to plugin parameters not in options page
            $this->plugin_params_capability='manage_options';
            //access to options page
            $this->plugin_settings_capability='manage_options';






            //wrapper for wlog not in muplugins
            if ( !function_exists('wlog') ) {
              function wlog($log, $text){}
            }
            if ( !function_exists('wlogt') ) {
              function wlogt($log, $text, $array){}
            }

            if ( !function_exists('print_tab') ) {
              function print_tab($var){
                echo '<pre>';
                print_r($var);
                echo '</pre>';
              }
            }
			if (!function_exists('write_log')) {
				function write_log($log) {
					if (true === WP_DEBUG) {
						if (is_array($log) || is_object($log)) {
							error_log(print_r($log, true));
						} else {
							error_log($log);
						}
					}
				}
			}

			// definit les endpoints (avec hook pour modifs eventuelles)
            $this->api_endpoints = apply_filters ( $this->plugin_prefix .'endpoints',
			 array(
				'myaccount' => get_option( $this->plugin_prefix . 'myaccount', 'mon-compte' ),
              	'qrcr' => get_option( $this->plugin_prefix . 'qrcr', 'qrcr' ),
            	  ));
			// enregistre les actions pour activation desactivation du plugin
			// (endpoints et rewrite rules, ...)
			//register_activation_hook(__FILE__, array($this, 'plugin_activation'));
			//register_deactivation_hook(__FILE__, array($this, 'plugin_deactivation'));

			// initialisation du plugin
            add_action( 'init', array( $this, 'plugin_init' ) );

			// gere les redirections endpoints
			add_action( 'template_redirect', array( $this, 'find_template'));




        }

        public function plugin_init() {
			// internationalisation
            $this->localise();
			// charge les fichiers includes
			$this->includes();
            if (is_admin()) {
               $this->admin= new WPQRC_Admin;
            }
       }

        public function localise() {
            // Load language files from the plugin folder
            load_plugin_textdomain( $this->plugin_textdomain, false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
            //load_plugin_textdomain('wp-fullcalendar', false, dirname( plugin_basename( __FILE__ ) ).'/includes/langs');
            // Internationalize the plugin with possibility to change locale
            //$locale = apply_filters( 'plugin_locale', get_locale(), $this->plugin_textdomain);
            //load_textdomain($this->plugin_textdomain, $this->plugin_path . 'languages/.$this->plugin_textdomain.'-'.$locale.'.mo');
        }

        public function includes() {
          if (is_admin()) {
            include_once( 'includes/class-wpqrc-admin.php' );
          }
        }

        /*
        public function plugin_activation() {
            foreach( $this->api_endpoints as $ep ) {
                add_rewrite_endpoint( $ep, EP_ROOT );
            }
            // recreation des regles de re-ecritures avec les nouveaux endpoints
            flush_rewrite_rules();
        }

        public function plugin_deactivation() {
			flush_rewrite_rules();
		}
		*/
		public function find_template($template){
            global $wp;
			//print_tab($wp);
            //print_tab($_SERVER);
			$args=explode('/',$wp->request);
            // Check the page url and display the template if query-vars ok
            // end point ep and and point key
			if (!empty($args)) {
            	foreach( $this->api_endpoints as $epk=>$ep ) {
					if ($args[0] == $ep && file_exists($this->plugin_template_path.$epk.'.php')) {
						include ($this->plugin_template_path.$epk.'.php');
						break;
					}
            	}
			}
			return false;
		}


   } //end of WordPress_Cooperative class
}// if exists WordPress_Cooperative class

// create instance
$wpqrc = new wpqrc;
